@@ -1,5 +1,8 @@
 package HTTP::Tiny::Patch::LogAny;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.03'; # VERSION
+
 use 5.010001;
 use strict;
 no warnings;
@@ -7,13 +10,11 @@ no warnings;
 use Module::Patch 0.12 qw();
 use base qw(Module::Patch);
 
-our $VERSION = '0.02'; # VERSION
-
 our %config;
 
 my $p_request = sub {
-    require Log::Any;
-    my $log = Log::Any->get_logger;
+    require Log::Any::IfLOG;
+    my $log = Log::Any::IfLOG->get_logger;
 
     my $ctx = shift;
     my $orig = $ctx->{orig};
@@ -104,7 +105,7 @@ HTTP::Tiny::Patch::LogAny - Log HTTP::Tiny with Log::Any
 
 =head1 VERSION
 
-This document describes version 0.02 of HTTP::Tiny::Patch::LogAny (from Perl distribution HTTP-Tiny-Patch-LogAny), released on 2015-02-05.
+This document describes version 0.03 of HTTP::Tiny::Patch::LogAny (from Perl distribution HTTP-Tiny-Patch-LogAny), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -155,7 +156,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/HTTP-Tiny-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-HTTP-Tiny-Patch-LogAny>.
+Source repository is at L<https://github.com/sharyanto/perl-HTTP-Tiny-Patch-LogAny>.
 
 =head1 BUGS
 
